@@ -531,12 +531,20 @@ def init_basicauth(config):
         # this is so ugly but httplib doesn't use
         # a logger object or such
         def new_method(self, *args, **kwargs):
-            self._orig_stdout = sys.stdout
-            sys.stdout = StringIO()
-            meth(self, *args, **kwargs)
-            hdr = sys.stdout.getvalue()
-            sys.stdout = self._orig_stdout
-            del self._orig_stdout
+            # check if this is a recursive call (note: we do not
+            # have to care about thread safety)
+            is_rec_call = getattr(self, '_orig_stdout', None) is not None
+            try:
+                if not is_rec_call:
+                    self._orig_stdout = sys.stdout
+                    sys.stdout = StringIO()
+                meth(self, *args, **kwargs)
+                hdr = sys.stdout.getvalue()
+            finally:
+                # restore original stdout
+                if not is_rec_call:
+                    sys.stdout = self._orig_stdout
+                    del self._orig_stdout
             for i in hdrs:
                 if ishdr:
                     hdr = re.sub(r'%s:[^\\r]*\\r\\n' % i, '', hdr)
@@ -571,9 +579,10 @@ def init_basicauth(config):
         cookiejar.load(ignore_discard=True)
     except IOError:
         try:
-            fd = os.open(cookie_file, os.O_CREAT | os.O_WRONLY | os.O_TRUNC, mode=0o600)
+            fd = os.open(cookie_file, os.O_CREAT | os.O_WRONLY | os.O_TRUNC, 0o600)
             os.close(fd)
-        except:
+        except IOError:
+            # hmm is any good reason why we should catch the IOError?
             #print 'Unable to create cookiejar file: \'%s\'. Using RAM-based cookies.' % cookie_file
             cookiejar = CookieJar()
 
@@ -914,6 +923,8 @@ def get_config(override_conffile=None,
                     api_host_options[apiurl][key] = cp.getboolean(url, key)
                 else:
                     api_host_options[apiurl][key] = cp.get(url, key)
+        if cp.has_option(url, 'build-root', proper=True):
+            api_host_options[apiurl]['build-root'] = cp.get(url, 'build-root', raw=True)
 
         if not 'sslcertck' in api_host_options[apiurl]:
             api_host_options[apiurl]['sslcertck'] = True
